pecos.qeclib.steane.preps.encoding\_circ
========================================

.. automodule:: pecos.qeclib.steane.preps.encoding_circ











   .. rubric:: Classes

   .. autosummary::

      EncodingCircuit
